@@ -3,7 +3,6 @@ package App::ListOrgAnniversaries;
 use 5.010;
 use strict;
 use warnings;
-use experimental 'smartmatch';
 use Log::ger;
 
 use App::OrgUtils;
@@ -14,9 +13,9 @@ use Exporter 'import';
 use Lingua::EN::Numbers::Ordinate;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-04-06'; # DATE
+our $DATE = '2023-07-12'; # DATE
 our $DIST = 'App-OrgUtils'; # DIST
-our $VERSION = '0.485'; # VERSION
+our $VERSION = '0.486'; # VERSION
 
 our @EXPORT_OK = qw(list_org_anniversaries);
 
@@ -35,13 +34,13 @@ sub _process_hl {
     if ($args->{has_tags} || $args->{lacks_tags}) {
         my $tags = [$hl->get_tags];
         if ($args->{has_tags}) {
-            for (@{ $args->{has_tags} }) {
-                return unless $_ ~~ @$tags;
+            for my $tag (@{ $args->{has_tags} }) {
+                return unless grep { $_ eq $tag } @$tags;
             }
         }
         if ($args->{lacks_tags}) {
-            for (@{ $args->{lacks_tags} }) {
-                return if $_ ~~ @$tags;
+            for my $tag (@{ $args->{lacks_tags} }) {
+                return if grep { $_ eq $tag } @$tags;
             }
         }
     }
@@ -331,7 +330,7 @@ App::ListOrgAnniversaries - List all anniversaries in Org files
 
 =head1 VERSION
 
-This document describes version 0.485 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2023-04-06.
+This document describes version 0.486 of App::ListOrgAnniversaries (from Perl distribution App-OrgUtils), released on 2023-07-12.
 
 =head1 SYNOPSIS
 
